@@ -125,6 +125,10 @@ class EngagementRateFB:
                     ["page_id", "date"]
                 )["fan_count"].fillna(method="bfill")
 
+                df_posts_full = df_posts_full.sort_values("date").drop_duplicates(
+                    subset=["post_id"], keep="last"
+                )
+
                 df_posts_full["group"] = df_posts_full["page_id"].apply(
                     lambda pid: general_utils.get_group(pid, groups)
                 )
